==> openai_search-2.0.13.tar.gz: openai_search/js/openai_search.js <==
// Get the value of the use_javascript from drupalSettings
var use_javascript = drupalSettings.openai_search.use_javascript;
console.log("node type is " + drupalSettings.openai_search.node_type);
var node_type = drupalSettings.openai_search.node_type;
var ai_url = drupalSettings.openai_search.ai_url;

function waitForElm(selector) {
  return new Promise(resolve => {
    if (document.querySelector(selector)) {
      return resolve(document.querySelector(selector));
    }

    const observer = new MutationObserver(mutations => {
      if (document.querySelector(selector)) {
        resolve(document.querySelector(selector));
        observer.disconnect();
      }
    });

    observer.observe(document.body, {
      childList: true,
      subtree: true
    });
  });
}

waitForElm('#js-submit').then((elm) => {
  document.getElementById('js-submit').addEventListener('click', function(e) {
    // Prevent the default form submission
    if (use_javascript === 1) {
      e.preventDefault();
    }
    else {
      return;
    }
    // change the id of spinner to be visible
    document.getElementById('wtk-ai-spinner').style.display = 'block';
    // Get the search query
    var searchQuery = document.getElementById('user-search-id').value;
    // Send a request to the server with the search query url friendly as an argument to http://main-bvxea6i-is5ueuku5nw4g.us.platformsh.site/json
    // make searchQuery url friendly
    // make searchQuery url friendly
    searchQuery = searchQuery.replace(/ /g, '+');
    // searchQuery = searchQuery.replace(' ', '%20');
    if (node_type == "private_gpts") {
      var url = drupalSettings.openai_search.restful_url + "/" + ai_url + "/" + searchQuery + '?UNIQUE_SESSION_COOKIE_NAME=' + drupalSettings.openai_search.session_id;
    }
    else {
      var url = drupalSettings.openai_search.restful_url + "/" + searchQuery + '?UNIQUE_SESSION_COOKIE_NAME=' + drupalSettings.openai_search.session_id;
    }
    console.log("url is " + url);
    // Get the response from the server
    fetch(url, {
      method: 'GET',
      headers: {
        'Accept': 'application/json',
      },
    })
      .then(response => response.json())
      .then(response=> {
        if (response) {
          document.getElementById('wtk-ai-spinner').style.display = 'none';
          // Display the response
          // Determine which key to use: "documents" (an array) or "response" (a string)
          var data = "";
          if (response.documents) {
            // Assume documents is an array; join its items with a newline
            data = response.documents;
          } else if (response.response) {
            data = response.response;
          }
          
          // If data is an object or array, stringify it
          if (typeof data === 'object') {
            data = JSON.stringify(data);
            // replace any brackets with a <br/> tag
            data = data.replace(/[\[\]"]+/g, '');
          }

          // Parse the response if it's a JSON string
          try {
            let parsedData = JSON.parse(data);
            data = parsedData;
          } catch (e) {
            // If it's not valid JSON, keep the original string
          }
          
          // Decode HTML entities first
          var tempDiv = document.createElement('div');
          tempDiv.innerHTML = data;
          data = tempDiv.textContent || tempDiv.innerText;
          
          // format any urls in the data to be clickable and open in a new window
          var regex = /(https?:\/\/[^\s]+)/g;
          // make sure any urls are clickable
          data = data.toString().replace(regex, "<a href='$1' target='_blank'>$1</a>");
          
          // append the data to the id of search-history-id in the textarea.
          var textarea = document.getElementById('search-history-id');
          // get the text the user entered in the textfield with id user-search-id and append it to the textarea
          var user_search = document.getElementById('user-search-id').value;
          textarea.innerHTML += '<b><i>' + user_search + '</i></b><br>';
          
          // Now render the decoded HTML
          textarea.innerHTML += data + '<br>';
          // clear the user search textfield
          document.getElementById('user-search-id').value = '';
          // scroll to the bottom of the textarea
          //textarea.scrollTop = textarea.scrollHeight;
        }
      });

  });
});

==> openai_search-2.0.17.tar.gz: openai_search/js/openai_search.js <==
// Get the value of the use_javascript from drupalSettings
var use_javascript = drupalSettings.openai_search.use_javascript;
var node_type = drupalSettings.openai_search.node_type;
var ai_url = drupalSettings.openai_search.ai_url;

console.log("ai_url is " + ai_url + " hello");

function waitForElm(selector) {
  return new Promise(resolve => {
    if (document.querySelector(selector)) {
      return resolve(document.querySelector(selector));
    }

    const observer = new MutationObserver(mutations => {
      if (document.querySelector(selector)) {
        resolve(document.querySelector(selector));
        observer.disconnect();
      }
    });

    observer.observe(document.body, {
      childList: true,
      subtree: true
    });
  });
}

waitForElm('#js-submit').then((elm) => {
  document.getElementById('js-submit').addEventListener('click', function(e) {
    // Prevent the default form submission
    if (use_javascript === 1) {
      e.preventDefault();
    }
    else {
      return;
    }
    // change the id of spinner to be visible
    document.getElementById('wtk-ai-spinner').style.display = 'block';
    // Get the search query
    var searchQuery = document.getElementById('user-search-id').value;
    // Send a request to the server with the search query url friendly as an argument to http://main-bvxea6i-is5ueuku5nw4g.us.platformsh.site/json
    // make searchQuery url friendly
    // make searchQuery url friendly
    searchQuery = searchQuery.replace(/ /g, '+');
    // searchQuery = searchQuery.replace(' ', '%20');
    if (node_type == "private_gpts") {
      var url = ai_url + "/" + searchQuery + '?UNIQUE_SESSION_COOKIE_NAME=' + drupalSettings.openai_search.session_id;
    }
    console.log("url is " + url);
    // Get the response from the server
    fetch(url, {
      method: 'GET',
      headers: {
        'Accept': 'application/json',
      },
    })
      .then(response => response.json())
      .then(response=> {
        if (response) {
          document.getElementById('wtk-ai-spinner').style.display = 'none';
          // Display the response
          // Determine which key to use: "documents" (an array) or "response" (a string)
          var data = "";
          if (response.documents) {
            // Assume documents is an array; join its items with a newline
            data = response.documents;
          } else if (response.response) {
            data = response.response;
          }
          
          // If data is an object or array, stringify it
          if (typeof data === 'object') {
            data = JSON.stringify(data);
            // replace any brackets with a <br/> tag
            data = data.replace(/[\[\]"]+/g, '');
          }

          // Parse the response if it's a JSON string
          try {
            let parsedData = JSON.parse(data);
            data = parsedData;
          } catch (e) {
            // If it's not valid JSON, keep the original string
          }
          
          // Decode HTML entities first
          var tempDiv = document.createElement('div');
          tempDiv.innerHTML = data;
          data = tempDiv.textContent || tempDiv.innerText;
          
          // format any urls in the data to be clickable and open in a new window
          var regex = /(https?:\/\/[^\s]+)/g;
          // make sure any urls are clickable
          data = data.toString().replace(regex, "<a href='$1' target='_blank'>$1</a>");
          
          // append the data to the id of search-history-id in the textarea.
          var textarea = document.getElementById('search-history-id');
          // get the text the user entered in the textfield with id user-search-id and append it to the textarea
          var user_search = document.getElementById('user-search-id').value;
          textarea.innerHTML += '<b><i>' + user_search + '</i></b><br>';
          
          // Now render the decoded HTML
          textarea.innerHTML += data + '<br>';
          // clear the user search textfield
          document.getElementById('user-search-id').value = '';
          // scroll to the bottom of the textarea
          //textarea.scrollTop = textarea.scrollHeight;
        }
      });

  });
});
